The tse.py package
==================

A Python package to access security modules (TSE) of the German 
Fiscal Authority.

The German Friscal Authority has determined that the transactions 
of all cash register systems used on the German market must be recorded
unchangeably. Certified external storage media are used for this purpose. 
The storage is accessed via certified libraries or APIs.

To interact with the TSEs, the package implements a vendor-independent API. 
Currently, TSEs from Epson are supported. Support for other manufacturers 
is planned for the future.

Documentation: `https://ccodein.gitlab.io/tse.py <https://ccodein.gitlab.io/tse.py>`_

Gitlab Project: `https://gitlab.com/ccodein/tse.py <https://gitlab.com/ccodein/tse.py>`_

